import QtQuick 1.0

Item {
    id: rect
    property int margin: 16
    property alias text: innerText.text
    property alias icon: iconImage.source
    property Menu child

    property alias mouseArea: mouseArea

    property bool expanded: false

    width: row.width + margin
    height: parent.height
    BorderImage {
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        height: 22
        source: "images/menubaritem-background-expanded.png"
        border {
            left: 5
            right: 5
            top: 0
            bottom: 0
        }
        visible: expanded
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        hoverEnabled: true
    }

    Row {
        id: row
        x: margin / 2
        spacing: 4
        Image {
            id: iconImage
            width: 22
            height: 22
            visible: source != ""
        }
        Text {
            id: innerText
            verticalAlignment: Text.AlignVCenter
            height: rect.height
            color: "white"
            visible: text != ""
        }
    }

    Connections {
        target: rect
        onExpandedChanged: {
            if (!child) {
                return;
            }
            if (expanded) {
                child.parent = rect
                child.visible = true

                var rootWindow = rect;
                while (rootWindow.parent) {
                    rootWindow = rootWindow.parent;
                }

                var rootRectX = rootWindow.mapFromItem(rect, 0, 0).x
                var outsideWidth = rootRectX + child.width - rootWindow.width
                child.x = outsideWidth > 0 ? -outsideWidth : 0
                child.y = rect.height - 2
            } else {
                child.visible = false
            }
        }
    }
}
