import QtQuick 1.0

Item {
    id: rect
    property int margin: 16
    property string text
    property string action
    property ListModel subMenuModel
    property Item subMenu
    property Item parentMenu

    property alias mouseArea: mouseArea

    property bool expanded: false

    width: itemText.width + (subMenuIndicator.visible ? (subMenuIndicator.width + margin) : 0) + margin
    height: 23

    BorderImage {
        visible: mouseArea.containsMouse
        width: parentMenu ? parentMenu.width : 0
        height: parent.height
        source: "images/menuitem-background-selected.png"
        border {
            left: 4
            top: 4
            right: 4
            bottom: 4
        }
    }

    MouseArea {
        id: mouseArea
        width: parentMenu ? parentMenu.width : 0
        height: parent.height
        hoverEnabled: true
        onClicked: {
            if (!subMenuModel && action) {
                menuBar.actionTriggered(action)
            }
        }
    }

    Text {
        id: itemText
        x: margin / 2
        height: parent.height
        text: rect.text
        verticalAlignment: Text.AlignVCenter
        color: "white"
    }

    Image {
        id: subMenuIndicator
        x: parentMenu.width - width
        anchors.verticalCenter: rect.verticalCenter
        source: "images/menuitem-submenuindicator.png"
        visible: subMenuModel != null
    }

    Connections {
        target: rect
        onExpandedChanged: {
            if (!subMenuModel) {
                return;
            }
            if (!subMenu) {
                var component = Qt.createComponent("Menu.qml");
                subMenu = component.createObject(rect);
                subMenu.model = subMenuModel;
            }
            if (expanded) {
                var rootWindow = rect;
                while (rootWindow.parent) {
                    rootWindow = rootWindow.parent;
                }

                var rootRectX = rootWindow.mapFromItem(rect, 0, 0).x + rect.width
                if (rootRectX + child.width < rootWindow.width) {
                    // Fit
                    subMenu.x = rect.x + rect.width
                } else {
                    // Does not fit
                    subMenu.x = rect.x - subMenu.width
                }
                subMenu.y = 0
                subMenu.visible = true
            } else {
                subMenu.visible = false
            }
        }
    }
}
